pub struct Attributes(/* private fields */);Expand description
Attribute bits for a mapping in a page table.
Implementations
Sourceimpl Attributes
impl Attributes
pub const VALID: Self
pub const TABLE_OR_PAGE: Self
pub const ATTRIBUTE_INDEX_0: Self
pub const ATTRIBUTE_INDEX_1: Self
pub const ATTRIBUTE_INDEX_2: Self
pub const ATTRIBUTE_INDEX_3: Self
pub const ATTRIBUTE_INDEX_4: Self
pub const ATTRIBUTE_INDEX_5: Self
pub const ATTRIBUTE_INDEX_6: Self
pub const ATTRIBUTE_INDEX_7: Self
pub const OUTER_SHAREABLE: Self
pub const INNER_SHAREABLE: Self
pub const NS: Self
pub const USER: Self
pub const READ_ONLY: Self
pub const ACCESSED: Self
pub const NON_GLOBAL: Self
Sourcepub const GP: Self
pub const GP: Self
Guarded Page - indirect forward edge jumps expect an appropriate BTI landing pad.
pub const DBM: Self
Sourcepub const UXN: Self
pub const UXN: Self
Unprivileged Execute-never, or just Execute-never if only one privilege level is supported.
pub const SWFLAG_0: Self
pub const SWFLAG_1: Self
pub const SWFLAG_2: Self
pub const SWFLAG_3: Self
pub const PXN_TABLE: Self
pub const XN_TABLE: Self
pub const AP_TABLE_NO_EL0: Self
pub const AP_TABLE_NO_WRITE: Self
pub const NS_TABLE: Self
Sourceimpl Attributes
impl Attributes
Sourcepub const fn bits(&self) -> usize
pub const fn bits(&self) -> usize
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: usize) -> Option<Self>
pub const fn from_bits(bits: usize) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: usize) -> Self
pub const fn from_bits_truncate(bits: usize) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: usize) -> Self
pub const fn from_bits_retain(bits: usize) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Attributes
impl Attributes
Sourcepub const fn iter(&self) -> Iter<Attributes>
pub const fn iter(&self) -> Iter<Attributes>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Attributes>
pub const fn iter_names(&self) -> IterNames<Attributes>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Attributes
impl Attributes
Sourcepub const SHAREABILITY_MASK: Self = Self::INNER_SHAREABLE
pub const SHAREABILITY_MASK: Self = Self::INNER_SHAREABLE
Mask for the bits determining the shareability of the mapping.
Sourcepub const ATTRIBUTE_INDEX_MASK: Self = Self::ATTRIBUTE_INDEX_7
pub const ATTRIBUTE_INDEX_MASK: Self = Self::ATTRIBUTE_INDEX_7
Mask for the bits determining the attribute index of the mapping.