UpdatableDescriptor

Struct UpdatableDescriptor 

pub struct UpdatableDescriptor<'a> { /* private fields */ }

Implementations

Source

impl<'a> UpdatableDescriptor<'a>

pub fn level(&self) -> usize

Returns the level in the page table hierarchy at which this descriptor appears

pub fn updated(&self) -> bool

Whether the descriptor was updated as a result of a call to set() or modify_flags()

pub fn is_table(&self) -> bool

Returns whether this descriptor represents a table mapping. In this case, the output address refers to a next level table.

pub fn bits(&self) -> usize

Returns the bit representation of the underlying descriptor

pub fn set(&mut self, pa: PhysicalAddress, flags: Attributes) -> Result<(), ()>

Assigns the underlying descriptor according to pa and `flags, provided that doing so is permitted under BBM rules

pub fn output_address(&self) -> PhysicalAddress

Returns the physical address to which this descriptor refers

Depending on the flags this could be the address of a subtable, a mapping, or (if it is not a valid mapping) entirely arbitrary.

pub fn flags(&self) -> Attributes

Returns the flags of this descriptor

pub fn modify_flags( &mut self, set: Attributes, clear: Attributes, ) -> Result<(), ()>

Modifies the descriptor by setting or clearing its flags.