pub enum MapError {
AddressRange(VirtualAddress),
InvalidVirtualAddress(VirtualAddress),
RegionBackwards(MemoryRegion),
PteUpdateFault(usize),
InvalidFlags(Attributes),
BreakBeforeMakeViolation(MemoryRegion),
}Expand description
An error attempting to map some range in the page table.
Variants
AddressRange(VirtualAddress)
The address requested to be mapped was out of the range supported by the page table configuration.
InvalidVirtualAddress(VirtualAddress)
The address requested to be mapped was not valid for the mapping in use.
RegionBackwards(MemoryRegion)
The end of the memory region is before the start.
PteUpdateFault(usize)
There was an error while updating a page table entry.
InvalidFlags(Attributes)
The requested flags are not supported for this mapping
BreakBeforeMakeViolation(MemoryRegion)
Updating the range violates break-before-make rules and the mapping is live