pub struct UpdatableDescriptor<'a> { /* private fields */ }Implementations
Sourceimpl<'a> UpdatableDescriptor<'a>
impl<'a> UpdatableDescriptor<'a>
Sourcepub fn level(&self) -> usize
pub fn level(&self) -> usize
Returns the level in the page table hierarchy at which this descriptor appears
Sourcepub fn updated(&self) -> bool
pub fn updated(&self) -> bool
Whether the descriptor was updated as a result of a call to set() or modify_flags()
Sourcepub fn is_table(&self) -> bool
pub fn is_table(&self) -> bool
Returns whether this descriptor represents a table mapping. In this case, the output address refers to a next level table.
Sourcepub fn set(&mut self, pa: PhysicalAddress, flags: Attributes) -> Result<(), ()>
pub fn set(&mut self, pa: PhysicalAddress, flags: Attributes) -> Result<(), ()>
Assigns the underlying descriptor according to pa and `flags, provided that doing so is
permitted under BBM rules
Sourcepub fn output_address(&self) -> PhysicalAddress
pub fn output_address(&self) -> PhysicalAddress
Returns the physical address to which this descriptor refers
Depending on the flags this could be the address of a subtable, a mapping, or (if it is not a valid mapping) entirely arbitrary.
Sourcepub fn flags(&self) -> Attributes
pub fn flags(&self) -> Attributes
Returns the flags of this descriptor
Sourcepub fn modify_flags(
&mut self,
set: Attributes,
clear: Attributes,
) -> Result<(), ()>
pub fn modify_flags( &mut self, set: Attributes, clear: Attributes, ) -> Result<(), ()>
Modifies the descriptor by setting or clearing its flags.